aboutsummaryrefslogtreecommitdiff
path: root/src/net/netdevice.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/net/netdevice.c')
-rw-r--r--src/net/netdevice.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/net/netdevice.c b/src/net/netdevice.c
index 5af9c6d..283632f 100644
--- a/src/net/netdevice.c
+++ b/src/net/netdevice.c
@@ -498,10 +498,11 @@ int register_netdev ( struct net_device *netdev ) {
uint32_t seed;
int rc;
- /* Create device name */
+ /* Record device index and create device name */
+ netdev->index = ifindex++;
if ( netdev->name[0] == '\0' ) {
snprintf ( netdev->name, sizeof ( netdev->name ), "net%d",
- ifindex++ );
+ netdev->index );
}
/* Set initial link-layer address, if not already set */